<?php

/**
 * Settings form.
 */
function noderef_image_helper_settings_form() {
  $form = array();

  $form['#submit'][] = 'noderef_image_helper_settings_form_submit';

  $types = node_get_types('names');
  $form['noderef_image_helper_image_node_type'] = array(
    '#type' => 'select',
    '#title' => t('Image node type'),
    '#default_value' => noderef_image_helper_image_node_type(),
    '#options' => $types,
    '#description' => t('Select the node type which is used for images.'),
  );
  $options = array();
  foreach (content_fields() as $field) {
    if ($field['type'] == 'filefield') {
      $options[$field['field_name']] = $field['field_name'] . ' - ' . $types[$field['type_name']];
    }
  }
  $form['noderef_image_helper_image_field_name'] = array(
    '#type' => 'select',
    '#title' => t('Image fieldname'),
    '#default_value' => noderef_image_helper_image_field_name(),
    '#options' => $options,
    '#description' => t('Select cck field used for images. Only fields of type <em>filefield</em> are shown.'),
  );

  $options = array();
  foreach (imagecache_presets() as $preset) {
    $options[$preset['presetname']] = $preset['presetname'];
  }
  $form['noderef_image_helper_preview_preset'] = array(
    '#type' => 'select',
    '#title' => t('Image preview preset'),
    '#default_value' => noderef_image_helper_preview_preset(),
    '#options' => $options,
    '#description' => t('Select the imagecache preset used for image previews.'),
  );
  $options = array();
  $options[''] = t('< built-in >');
  foreach (views_get_all_views() as $view) {
    if ($view->display['default']->display_options['row_plugin'] == 'noderef_image') {
      $options[$view->name] = $view->name;
    }
  }
  $form['noderef_image_helper_browsing_view'] = array(
    '#type' => 'select',
    '#title' => t('Browsing view'),
    '#default_value' => noderef_image_helper_browsing_view(),
    '#options' => $options,
    '#description' => t('Select the view which is used to browse the images. Only views which use the row style <em>Noderef image</em> can be selected.'),
  );

  $form['noderef_image_helper_reference'] = array(
    '#type' => 'checkbox',
    '#title' => t('Load referenced image node'),
    '#default_value' => noderef_image_helper_reference(),
    '#description' => t('Evaluating the reference can lead to performance impact.'),
  );

  $presets_available = array();
  foreach (imagecache_presets() as $preset_id => $preset) {
    $presets_available[$preset_id] = $preset['presetname'];
  }
  $form['noderef_image_helper_presets'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Formatter presets'),
    '#description' => t('Imagecache presets that are enabled for node reference formatters.'),
    '#options' => $presets_available,
    '#default_value' => noderef_image_helper_presets(),
  );

  return system_settings_form($form);
}

/**
 * Settings form submit.
 */
function noderef_image_helper_settings_form_submit($form, &$form_state) {
  // clear preset cache
  cache_clear_all('content_type_info', content_cache_tablename(), TRUE);
  // theme registry needs to be rebuilt
  drupal_rebuild_theme_registry();
}
